package com.jpsoft.picc.modules.business.controller;

import com.github.pagehelper.Page;
import com.jpsoft.picc.modules.business.entity.StudentApplicationRecord;
import com.jpsoft.picc.modules.business.service.StudentApplicationRecordService;
import com.jpsoft.picc.modules.common.dto.Sort;
import com.jpsoft.picc.modules.common.dto.MessageResult;
import com.jpsoft.picc.modules.common.utils.PojoUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.*;

@RestController
@RequestMapping("/business/studentApplicationRecord")
@Api(description = "studentApplicationRecord")
public class StudentApplicationRecordController {
    private Logger logger = LoggerFactory.getLogger(getClass());

    @Autowired
    private StudentApplicationRecordService studentApplicationRecordService;

    @ApiOperation(value="创建空记录")
    @GetMapping("create")
    public MessageResult<StudentApplicationRecord> create(){
        MessageResult<StudentApplicationRecord> msgResult = new MessageResult<>();

        StudentApplicationRecord studentApplicationRecord = new StudentApplicationRecord();

        msgResult.setData(studentApplicationRecord);
        msgResult.setResult(true);

        return msgResult;
    }
    
    @ApiOperation(value="添加信息")
    @PostMapping("add")
    public MessageResult<StudentApplicationRecord> add(@RequestBody StudentApplicationRecord studentApplicationRecord,@RequestAttribute String subject){
        MessageResult<StudentApplicationRecord> msgResult = new MessageResult<>();

        try {
            studentApplicationRecord.setId(UUID.randomUUID().toString());
            studentApplicationRecord.setDelFlag(false);
            studentApplicationRecord.setCreateBy(subject);
            studentApplicationRecord.setCreateTime(new Date());
            
            int affectCount = studentApplicationRecordService.insert(studentApplicationRecord);

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(studentApplicationRecord);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("数据库添加失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

    @ApiOperation(value="获取信息")
    @GetMapping("edit/{id}")
    public MessageResult<StudentApplicationRecord> edit(@PathVariable("id") String id){
        MessageResult<StudentApplicationRecord> msgResult = new MessageResult<>();

        try {
            StudentApplicationRecord studentApplicationRecord = studentApplicationRecordService.get(id);

            if (studentApplicationRecord != null) {
                msgResult.setResult(true);
                msgResult.setData(studentApplicationRecord);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("数据库不存在该记录!");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

    @ApiOperation(value="更新用户")
    @PostMapping("update")
    public MessageResult<StudentApplicationRecord> update(@RequestBody StudentApplicationRecord studentApplicationRecord,@RequestAttribute String subject){
        MessageResult<StudentApplicationRecord> msgResult = new MessageResult<>();

        try {
            studentApplicationRecord.setUpdateBy(subject);
            studentApplicationRecord.setUpdateTime(new Date());
            
            int affectCount = studentApplicationRecordService.update(studentApplicationRecord);

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(studentApplicationRecord);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("数据库更新失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

	@ApiOperation(value="删除")
    @PostMapping("delete/{id}")
    public MessageResult<Integer> delete(@PathVariable("id") String id,@RequestAttribute String subject){
        MessageResult<Integer> msgResult = new MessageResult<>();

        try {
            StudentApplicationRecord studentApplicationRecord = studentApplicationRecordService.get(id);
            studentApplicationRecord.setDelFlag(true);
            studentApplicationRecord.setUpdateBy(subject);
            studentApplicationRecord.setUpdateTime(new Date());

            int affectCount = studentApplicationRecordService.update(studentApplicationRecord);

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(affectCount);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("删除失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }


    @ApiOperation(value="批量删除")
    @PostMapping("batchDelete")
    public MessageResult<Integer> batchDelete(@RequestBody List<String> idList,@RequestAttribute String subject){
        MessageResult<Integer> msgResult = new MessageResult<>();

        try {
            int affectCount = 0;

            for (String id : idList) {
                StudentApplicationRecord studentApplicationRecord = studentApplicationRecordService.get(id);
                studentApplicationRecord.setDelFlag(true);
                studentApplicationRecord.setUpdateBy(subject);
                studentApplicationRecord.setUpdateTime(new Date());

                affectCount += studentApplicationRecordService.update(studentApplicationRecord);
            }

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(affectCount);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("删除失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

    @ApiOperation(value="列表")
    @RequestMapping(value = "pageList",method = RequestMethod.POST)
    public MessageResult<Map> pageList(
            String applicationId,
            @RequestParam(value="pageIndex",defaultValue="1") int pageIndex,
            @RequestParam(value="pageSize",defaultValue="20") int pageSize,
            @RequestAttribute String subject){

        //当前用户ID
        System.out.println(subject);

        MessageResult<Map> msgResult = new MessageResult<>();

        Map<String,Object> searchParams = new HashMap<>();

        List<Sort> sortList = new ArrayList<>();
        sortList.add(new Sort("create_time","asc"));

        if (StringUtils.isNotEmpty(applicationId)) {
            searchParams.put("applicationId",applicationId);
        }
        searchParams.put("delFlag",false);
        Page<StudentApplicationRecord> page = studentApplicationRecordService.pageSearch(searchParams,pageIndex,pageSize,true,sortList);

        msgResult.setResult(true);
        msgResult.setData(PojoUtils.pageWrapper(page));

        return msgResult;
    }
}
